setDefaults method
Optionally register a map of default values with Firebase Remote Config.
This is entirely optional – most apps will rely on per‑call defaults in expressions – but it can be useful for centralizing defaults in Dart.
Implementation
Future<void> setDefaults(Map<String, dynamic> defaults) async {
await ensureInitialized();
await _remoteConfig?.setDefaults(defaults);
}