RemoteConfigService class
Remote Config service used by Ensemble.
This module is responsible for:
- Fetching and activating Remote Config
- Providing
getValue,getAllValues,getInfo, andrefreshmethods for the core Ensemble runtime
- Available extensions
Constructors
- RemoteConfigService()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
ensureInitialized(
) → Future< void> - Initialize Remote Config
-
fetchAndActivate(
) → Future< void> - Fetch and activate latest Remote Config values
-
getAllValues(
) → Map< String, dynamic> -
Available on RemoteConfigService, provided by the RemoteConfigServiceDebug extension
Snapshot of all RC values, using the same typing rules as getValue with anulldefault. -
getInfo(
) → Map< String, dynamic> -
Available on RemoteConfigService, provided by the RemoteConfigServiceDebug extension
Debug information about the current RC state. -
getValue(
String key, dynamic defaultValue) → dynamic - Get a Remote Config value
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setDefaults(
Map< String, dynamic> defaults) → Future<void> - Optionally register a map of default values with Firebase Remote Config.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited